@@ -5,9 +5,18 @@ use strict;
 use warnings; no warnings qw(void once uninitialized numeric redefine);
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '1.004002';
+our $VERSION   = '1.006002';
 our @EXPORT_OK = qw< mkopt mkopt_hash _croak _carp >;
 
+BEGIN {
+	*_HAS_NATIVE_LEXICAL_SUB = ( $] ge '5.037002' )
+		? sub () { !!1 }
+		: sub () { !!0 };
+	*_HAS_MODULE_LEXICAL_SUB = ( $] ge '5.011002' and eval('require Lexical::Sub') )
+		? sub () { !!1 }
+		: sub () { !!0 };
+};
+
 sub _croak ($;@) { require Carp; my $fmt = shift; @_ = sprintf($fmt, @_); goto \&Carp::croak }
 sub _carp  ($;@) { require Carp; my $fmt = shift; @_ = sprintf($fmt, @_); goto \&Carp::carp }
 
@@ -26,6 +35,11 @@ my $_process_optlist = sub
 				my @not = $class->_exporter_expand_regexp("$1", $value, $global_opts);
 				++$not_want->{$_->[0]} for @not;
 			} :
+		($name =~ m{\A\![:-](.+)\z}) ?
+			do {
+				my @not = $class->_exporter_expand_tag("$1", $value, $global_opts);
+				++$not_want->{$_->[0]} for @not;
+			} :
 		($name =~ m{\A\!(.+)\z}) ?
 			(++$not_want->{$1}) :
 		($name =~ m{\A[:-](.+)\z}) ?
@@ -41,7 +55,14 @@ sub import
 {
 	my $class = shift;
 	my $global_opts = +{ @_ && ref($_[0]) eq q(HASH) ? %{+shift} : () };
-	$global_opts->{into} = caller unless exists $global_opts->{into};
+	
+	if ( defined $global_opts->{into} and $global_opts->{into} eq '-lexical' ) {
+		$global_opts->{lexical} = 1;
+		delete $global_opts->{into};
+	}
+	if ( not defined $global_opts->{into} ) {
+		$global_opts->{into} = caller;
+	}
 	
 	my @want;
 	my %not_want; $global_opts->{not} = \%not_want;
@@ -49,11 +70,13 @@ sub import
 	my $opts = mkopt(\@args);
 	$class->$_process_optlist($global_opts, $opts, \@want, \%not_want);
 	
+	$global_opts->{installer} ||= $class->_exporter_lexical_installer( $global_opts )
+		if $global_opts->{lexical};
+	
 	my $permitted = $class->_exporter_permitted_regexp($global_opts);
 	$class->_exporter_validate_opts($global_opts);
 	
-	for my $wanted (@want)
-	{
+	for my $wanted (@want) {
 		next if $not_want{$wanted->[0]};
 		
 		my %symbols = $class->_exporter_expand_sub(@$wanted, $global_opts, $permitted);
@@ -66,9 +89,16 @@ sub unimport
 {
 	my $class = shift;
 	my $global_opts = +{ @_ && ref($_[0]) eq q(HASH) ? %{+shift} : () };
-	$global_opts->{into} = caller unless exists $global_opts->{into};
 	$global_opts->{is_unimport} = 1;
 	
+	if ( defined $global_opts->{into} and $global_opts->{into} eq '-lexical' ) {
+		$global_opts->{lexical} = 1;
+		delete $global_opts->{into};
+	}
+	if ( not defined $global_opts->{into} ) {
+		$global_opts->{into} = caller;
+	}
+	
 	my @want;
 	my %not_want; $global_opts->{not} = \%not_want;
 	my @args = do { our %TRACKED; @_ ? @_ : keys(%{$TRACKED{$class}{$global_opts->{into}}}) };
@@ -99,6 +129,23 @@ sub unimport
 	}
 }
 
+# Returns a coderef suitable to be used as a sub installer for lexical imports.
+#
+sub _exporter_lexical_installer {
+	_HAS_NATIVE_LEXICAL_SUB and return sub {
+		my ( $sigilname, $sym ) = @{ $_[1] };
+		no warnings ( $] ge '5.037002' ? 'experimental::builtin' : () );
+		builtin::export_lexically( $sigilname, $sym );
+	};
+	_HAS_MODULE_LEXICAL_SUB and return sub {
+		my ( $sigilname, $sym ) = @{ $_[1] };
+		( $sigilname =~ /^\w/ )
+			? 'Lexical::Sub'->import( $sigilname, $sym )
+			: 'Lexical::Var'->import( $sigilname, $sym );
+	};
+	_croak( 'Lexical export requires Perl 5.37.2+ for native support, or Perl 5.11.2+ with the Lexical::Sub module' );
+}
+
 # Called once per import/unimport, passed the "global" import options.
 # Expected to validate the options and carp or croak if there are problems.
 # Can also take the opportunity to do other stuff if needed.
@@ -227,11 +274,12 @@ sub _exporter_expand_sub
 		my $generator = $class->can("$generatorprefix$name");
 		return $sigilname => $class->$generator($sigilname, $value, $globals) if $generator;
 		
-		my $sub = $class->can($name);
-		return $sigilname => $sub if $sub;
-		
-		# Could do this more cleverly, but this works.
-		if ($sigil ne '&') {
+		if ($sigil eq '&') {
+			my $sub = $class->can($name);
+			return $sigilname => $sub if $sub;
+		}
+		else {
+			# Could do this more cleverly, but this works.
 			my $evalled = eval "\\${sigil}${class}::${name}";
 			return $sigilname => $evalled if $evalled;
 		}
@@ -262,17 +310,7 @@ sub _exporter_install_sub
 	
 	my $into      = $globals->{into};
 	my $installer = $globals->{installer} || $globals->{exporter};
-
-	if ( $into eq '-lexical' or $globals->{lexical} ) {
-		$] ge '5.037002'
-			or _croak( 'Lexical export requires Perl 5.37.2 or above' );
-		$installer ||= sub {
-			my ( $sigilname, $sym ) = @{ $_[1] };
-			no warnings ( $] ge '5.037002' ? 'experimental::builtin' : () );
-			builtin::export_lexically( $sigilname, $sym );
-		};
-	}
-
+	
 	$name =
 		ref    $globals->{as}      ? $globals->{as}->($name) :
 		ref    $value_hash->{-as}  ? $value_hash->{-as}->($name) :
@@ -295,21 +333,23 @@ sub _exporter_install_sub
 		$name = "$prefix$name$suffix";
 	}
 	
-	my $sigilname = $sigil eq '&' ? $name : "$sigil$name";
+	my $sigilname = $sigil eq '&' ? $name : ( $sigil . $name );
 	
 #	if ({qw/$ SCALAR @ ARRAY % HASH & CODE/}->{$sigil} ne ref($sym)) {
 #		warn $sym;
 #		warn $sigilname;
 #		_croak("Reference type %s does not match sigil %s", ref($sym), $sigil);
 #	}
-		
+	
 	return ($$name = $sym)              if ref($name) eq q(SCALAR);
 	return ($into->{$sigilname} = $sym) if ref($into) eq q(HASH);
 	
 	no strict qw(refs);
 	our %TRACKED;
 	
-	if (ref($sym) eq 'CODE' and exists &{"$into\::$name"} and \&{"$into\::$name"} != $sym)
+	if ( ref($sym) eq 'CODE'
+	and ref($into) ? exists($into->{$name}) : exists(&{"$into\::$name"})
+	and $sym != ( ref($into) ? $into->{$name} : \&{"$into\::$name"} ) )
 	{
 		my ($level) = grep defined, $value_hash->{-replace}, $globals->{replace}, q(0);
 		my $action = {
@@ -329,10 +369,9 @@ sub _exporter_install_sub
 		
 		$action->(
 			$action == \&_croak
-				? "Refusing to overwrite existing sub '%s::%s' with sub '%s' exported by %s"
-				: "Overwriting existing sub '%s::%s' with sub '%s' exported by %s",
-			$into,
-			$name,
+				? "Refusing to overwrite existing sub '%s' with sub '%s' exported by %s"
+				: "Overwriting existing sub '%s' with sub '%s' exported by %s",
+			ref($into) ? $name : "$into\::$name",
 			$_[0],
 			$class,
 		);
@@ -489,15 +528,14 @@ L<Exporter::Tiny::Manual::Importing>
 Please report any bugs to
 L<https://github.com/tobyink/p5-exporter-tiny/issues>.
 
-=head1 SUPPORT
-
-B<< IRC: >> support is available through in the I<< #moops >> channel
-on L<irc.perl.org|http://www.irc.perl.org/channels.html>.
-
 =head1 SEE ALSO
 
+L<https://exportertiny.github.io/>.
+
 Simplified interface to this module: L<Exporter::Shiny>.
 
+Less tiny version, with more features: L<Exporter::Almighty>.
+
 Other interesting exporters: L<Sub::Exporter>, L<Exporter>.
 
 =head1 AUTHOR
@@ -506,7 +544,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2014, 2017, 2022 by Toby Inkster.
+This software is copyright (c) 2013-2014, 2017, 2022-2023 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
